@@ -18,7 +18,9 @@ from blechpy.plotting import palatability_plot as pal_plt, data_plot as datplt
 from blechpy import dio
 from blechpy.datastructures.objects import data_object
 from blechpy.utils import spike_sorting_GUI as ssg
-
+from scipy.ndimage import gaussian_filter1d
+import tables
+import scipy.io as sio
 
 class dataset(data_object):
     '''Stores information related to an intan recording directory, allows
@@ -80,22 +82,24 @@ class dataset(data_object):
         return new_root
 
     @Logger('Initializing Parameters')
-    def initParams(self, data_quality='clean', emg_port=None,
-                   emg_channels=None, car_keyword=None,
-                   car_group_areas=None,
-                   shell=False, dig_in_names=None,
-                   dig_out_names=None, accept_params=False):
+    def initParams(self, data_quality='hp', 
+                   emg_port=None, emg_channels=None, 
+                   car_keyword=None, car_group_areas=None,
+                   shell=False, dig_in_names=None, dig_out_names=None,
+                   accept_params=False):
         '''
         Initalizes basic default analysis parameters and allows customization
         of parameters
 
         Parameters (all optional)
         -------------------------
-        data_quality : {'clean', 'noisy'}
+        data_quality : {'clean', 'noisy', 'hp'}
             keyword defining which default set of parameters to use to detect
             headstage disconnection during clustering
             default is 'clean'. Best practice is to run blech_clust as 'clean'
-            and re-run as 'noisy' if too many early cutoffs occurr
+            and re-run as 'noisy' if too many early cutoffs occurr. 
+            Alternately run as 'hp' (high performance)
+            default parameter sets found in dio.defualts.clustering_params.json
         emg_port : str
             Port ('A', 'B', 'C') of EMG, if there was an EMG. None (default)
             will query user. False indicates no EMG port and not to query user
@@ -104,8 +108,8 @@ class dataset(data_object):
             default is None
         car_keyword : str
             Specifes default common average reference groups
-            defaults are found in CAR_defaults.json
-            Currently 'bilateral32' is only keyword available
+            defaults are found in dio.defaults.CAR_params.json
+            'bilateral32' and 'bilateral64' are available keywords 
             If left as None (default) user will be queries to select common
             average reference groups
         shell : bool
@@ -127,13 +131,14 @@ class dataset(data_object):
         '''
         # Get parameters from info.rhd
         file_dir = self.root_dir
-        rec_info = dio.rawIO.read_rec_info(file_dir)
+        rec_info = dio.rawIO.read_rec_info(file_dir, shell=shell)
         ports = rec_info.pop('ports')
         channels = rec_info.pop('channels')
         sampling_rate = rec_info['amplifier_sampling_rate']
         self.rec_info = rec_info
         self.sampling_rate = sampling_rate
 
+        # Get default parameters from files
         # Get default parameters from files
         clustering_params = dio.params.load_params('clustering_params', file_dir,
                                                    default_keyword=data_quality)
@@ -620,6 +625,8 @@ class dataset(data_object):
         self.process_status['extract_data'] = True
         self.save()
         print('\nData Extraction Complete\n--------------------')
+        
+        
 
     @Logger('Creating Trial List')
     def create_trial_list(self):
@@ -826,7 +833,7 @@ class dataset(data_object):
         return results
 
     @Logger('Running Blech Clust')
-    def blech_clust_run(self, data_quality=None, multi_process=True, n_cores=None, umap=False):
+    def blech_clust_run(self, data_quality=None, multi_process=True, n_cores=None, umap=True):
         '''Write clustering parameters to file and
         Run blech_process on each electrode using GNU parallel
 
@@ -1040,7 +1047,52 @@ class dataset(data_object):
 
         self.process_status['make_psth_arrays'] = True
         self.save()
+    
+    def make_psth_plots(self):
+        unit_table = self.get_unit_table()
+        save_dir = os.path.join(self.root_dir,'unit_psth_plots')
+        if os.path.isdir(save_dir):
+            shutil.rmtree(save_dir)
+        os.mkdir(save_dir)
+        
+        
+        dinmap = self.dig_in_mapping.query('spike_array ==True')
+        
+        for i, row in unit_table.iterrows():
+            un = row.unit_num
+            save_file = os.path.join(save_dir,'unit_'+str(un)+'_PSTH.svg')
+            datplt.plot_overlay_psth(rec_dir = self.root_dir, unit = un , plot_window=[-1500, 5000], bin_size = 500, din_map = dinmap, save_file=save_file)
+    
+    def make_raster_plots(self):
+        '''make raster plots with electrode noise for each unit  
+        '''
+        
+        unit_table = self.get_unit_table()
+        save_dir = os.path.join(self.root_dir, 'unit_raster_plots')
+        
+        if os.path.isdir(save_dir):
+            shutil.rmtree(save_dir)
+        os.mkdir(save_dir)
+        for i, row in unit_table.iterrows():
+            spike_times, _, _ = dio.h5io.get_unit_spike_times(self.root_dir, row['unit_name'], h5_file = self.h5_file) 
+            
+            waveforms, _, _ = dio.h5io.get_unit_waveforms(self.root_dir, row['unit_name'], h5_file = self.h5_file)
+            save_file = os.path.join(save_dir, row['unit_name']+'_raster')
+            datplt.plot_spike_raster([spike_times], [waveforms], save_file = save_file)
+            
+        self.save()
 
+    def make_ensemble_raster_plots(self):
+        save_dir = os.path.join(self.root_dir, 'raster_plots')
+        name = self.data_name
+        save_file = os.path.join(save_dir, name+'_ensemble_raster')
+        if os.path.isdir(save_dir):
+            shutil.rmtree(save_dir) 
+        os.mkdir(save_dir)     
+        
+        datplt.plot_ensemble_raster(self,save_file)
+        
+        
     @Logger('Calculating Palatability/Identity Metrics')
     def palatability_calculate(self, shell=False):
         pal_analysis.palatability_identity_calculations(self.root_dir,
@@ -1085,6 +1137,16 @@ class dataset(data_object):
         '''
         unit_table = dio.h5io.get_unit_table(self.root_dir, h5_file=self.h5_file)
         return unit_table
+    
+    def edit_unit_descriptor(self, unit_num, descriptor_key,descriptor_val):
+        '''
+        use this to edit unit table, i.e. if you made a mistake labeling a neuron in spike sorting
+        unit_num takes integers, corresponds to unit_num in get_unit_table()
+        descriptor_key takes string, can be "single_unit", "regular_spiking", or "fast_spiking"
+        descriptor_val takes boolean, can be True or False
+        '''
+        dio.h5io.edit_unit_descriptor(self.root_dir, unit_num, descriptor_key, descriptor_val, self.h5_file)
+        print("descriptor edit success")
 
     def circus_clust_run(self, shell=False):
         circ.prep_for_circus(self.root_dir, self.electrode_mapping,
@@ -1133,7 +1195,96 @@ class dataset(data_object):
         self.make_unit_arrays()
         self.units_similarity(shell=True)
         self.make_psth_arrays()
-
+        self.make_raster_plots()
+        
+    def export_TrialSpikeArrays2Mat(self):
+        h5 = tables.open_file(self.h5_file,'r+')
+        taste_dig_in = h5.list_nodes('/spike_trains')
+        loops = len(taste_dig_in)
+        tbl = {}
+        
+        names = self.dig_in_mapping[self.dig_in_mapping['spike_array'] == True]['name']
+        key = names.values.tolist()
+        spike_arrs = np.zeros(loops,dtype=np.object)
+        
+        for i in range(loops):
+            if i < len(taste_dig_in):
+                spike_arrs[i] = taste_dig_in[i].spike_array[:]
+        
+        nameparts = str.split(self.tbla_name, '_')
+        tbl['ID'] = nameparts[0]
+        tbl['tble'] = nameparts[-2]
+        tbl['spikes'] = spike_arrs
+        tbl['states'] = key
+        
+        ff = os.path.join(self.root_dir, 'matlab_exports') #make variable with folder name (file folder)
+        
+        if not os.path.exists(ff): #check if file folder exists, make if if not
+            os.makedirs(ff)
+            print("Directory created successfully")
+        
+        fn = self.tbla_name+'.mat' #make file name
+        fp = os.path.join(ff, fn) #make file path 
+        sio.savemat(fp,{'tbla':tbl}) #save tbla [tbl] with label "tbla", at file path fp
+        print('spike trains successfully exported to '+fp)
+        
+        h5.flush()
+        h5.close()
+        
+        #TODO: get this 
+    def get_spike_array_table(self):
+        h5 = tables.open_file(self.h5_file,'r+')
+        taste_dig_in = h5.list_nodes('/spike_trains')
+        loops = len(taste_dig_in)
+        tbl = {}
+        
+        names = self.dig_in_mapping[self.dig_in_mapping['spike_array'] == True]['name'].copy()
+        key = names.values.tolist()
+        spike_arrs = np.zeros(loops,dtype=np.object)
+        
+        
+        for i in range(loops):
+            if i < len(taste_dig_in):
+                spike_arrs[i] = taste_dig_in[i].spike_array[:]
+                
+        h5.flush()
+        h5.close()
+        
+        tbl['spikes'] = spike_arrs
+        tbl['name'] = key
+        
+        tbl = pd.DataFrame.from_dict(tbl)
+        tbl = tbl.explode('spikes')
+        tbl['din_trial'] = tbl.groupby(['name']).cumcount()
+        
+        din_trls = self.dig_in_trials.copy()
+        din_trls['din_trial'] = din_trls.groupby(['name']).cumcount()
+        
+        tbl = tbl.merge(din_trls, how = 'left', on = ['din_trial','name'])
+        
+        
+        
+        nameparts = str.split(self.data_name, '_')
+        tbl['ID'] = nameparts[0]
+        tbl['date'] = nameparts[-2]
+        tbl['rec_dir'] = self.root_dir
+        
+        unt_tbl = self.get_unit_table().copy()
+        elec_tbl = self.electrode_mapping.copy()
+        elec_tbl = elec_tbl.rename(columns = {'Electrode':'electrode'})
+        elec_tbl = elec_tbl[['electrode','area']]
+        unt_tbl = unt_tbl.merge(elec_tbl, how = 'left', on = 'electrode') 
+        
+        unt_tbl = unt_tbl.apply(lambda x: [x.tolist()], axis = 0)
+        unt_tbl = pd.concat([unt_tbl]*len(tbl), ignore_index = True)
+        
+        cols = ['unit_num','electrode','regular_spiking','fast_spiking', 'area']
+        tbl[cols] = unt_tbl[cols]
+        
+        cols.append('spikes')
+        tbl = tbl.explode(cols)
+        
+        return tbl
 
 def run_joblib_process(process):
     res = process.run()
@@ -1173,7 +1324,7 @@ def port_in_dataset(rec_dir=None, shell=False):
     if os.path.isfile(info_rhd):
         dat.initParams(shell=shell)
     else:
-        raise FileNotFoundError(f'{info.rhd} is required for proper dataset creation') 
+        raise FileNotFoundError(f'{info_rhd} is required for proper dataset creation') 
 
     status = dat.process_status
 
@@ -1253,7 +1404,7 @@ def port_in_dataset(rec_dir=None, shell=False):
                 snapshot_post = params['spike_snapshot']['Time after spike (ms)']
                 sd_params['spike_snapshot'] = [snapshot_pre, snapshot_post]
                 sd_params['sampling_rate'] = params['sampling_rate']
-                blechpy.utils.write_tools.write_dict_to_json(sd_params, sd_fn)
+                wt.write_dict_to_json(sd_params, sd_fn)
 
             c_fn = os.path.join(clust_dir, 'BlechClust_params.json')
             if not os.path.isfile(c_fn):
@@ -1263,7 +1414,7 @@ def port_in_dataset(rec_dir=None, shell=False):
                 c_params['threshold'] = params['clustering_params']['Convergence Criterion']
                 c_params['num_restarts'] = params['clustering_params']['GMM random restarts']
                 c_params['wf_amplitude_sd_cutoff'] = params['data_params']['Intra-cluster waveform amp SD cutoff']
-                blechpy.utils.write_tools.write_dict_to_json(c_params, c_fn)
+                wt.write_dict_to_json(c_params, c_fn)
 
             # To make: clust_dir/clustering_results/ clustering_results.json, rec_key.json, spike_id.npy
             # To make: detect_dir/data/cutoff_time.txt and detection_threshold.txt
@@ -1291,7 +1442,6 @@ def port_in_dataset(rec_dir=None, shell=False):
 
     return dat
 
-
 def validate_data_integrity(rec_dir, verbose=False):
     '''incomplete
     '''
@@ -1316,7 +1466,7 @@ def validate_data_integrity(rec_dir, verbose=False):
 
         tests['recording_info'] = 'PASS'
     except FileNotFoundError:
-        test['recording_info'] = 'MISSING'
+        tests['recording_info'] = 'MISSING'
     except Exception as e:
         info_size = os.path.getsize(os.path.join(rec_dir, 'info.rhd'))
         if info_size == 0:
@@ -1359,9 +1509,9 @@ def validate_data_integrity(rec_dir, verbose=False):
 
     missing_files = []
     file_list = os.listdir(rec_dir)
-    for x in file_expected:
+    for x in files_expected:
         if x not in file_list:
-            missing_file.append(x)
+            missing_files.append(x)
 
     if len(missing_files) == 0:
         tests['files'] = 'PASS'
@@ -1402,7 +1552,7 @@ def validate_data_integrity(rec_dir, verbose=False):
         chan_info = pd.DataFrame(columns=['port', 'channel', 'n_samples'])
         lengths = []
         min_samples = numbers['n_samples']
-        max_samples = number['n_samples']
+        max_samples = numbers['n_samples']
         for x in info['amplifier_channels']:
             fn = os.path.join(rec_dir, 'amp-%s.dat' % x['native_channel_name'])
             if os.path.basename(fn) in missing_files:
@@ -1420,7 +1570,8 @@ def validate_data_integrity(rec_dir, verbose=False):
             tests['data_traces'] = 'PASS'
 
         else:
-            test['data_traces'] = 'CUTOFF'
+            tests['data_traces'] = 'CUTOFF'
 
         numbers['max_recording_length (s)'] = max_samples/fs
         numbers['min_recording_length (s)'] = min_samples/fs
+
