@@ -123,7 +123,8 @@ class experiment(data_object):
             file_dirs = sorted(file_dirs, key=order_dict.get)
             file_dirs = [os.path.join(top_dirs.get(x), x) for x in file_dirs]
         else:
-            file_dirs = sorted(self.recording_dirs, key=order_dict.get)
+            file_dirs = sorted(self.recording_dirs, key=order_dict.get) #TODO: idk what is hapening with these key orders this is fucked
+            
             
         self.order_dict = order_dict
         self.recording_dirs = file_dirs
@@ -461,5 +462,23 @@ class experiment(data_object):
         else:
             print('No shell UI yet')
             return
-
+        
+    #def plot_held_session_rasters():
+    def get_electrode_unit_counts(self):
+        all_unit_table = pd.DataFrame()
+        for rd in self.recording_dirs:
+            dat = load_dataset(rd)
+            nm = dat.data_name
+            unit_table = dat.get_unit_table()
+            unit_table['rec'] = nm
+            all_unit_table = all_unit_table.append(unit_table)
+            
+        out = all_unit_table.groupby(['electrode','rec']).size().reset_index(name = 'n_units')
+        return out
+            
+    def export_electrode_unit_counts(self):
+        uc = self.get_electrode_unit_counts()
+        filename = os.path.join(self.root_dir,'electrode_unit_counts.csv')
+        uc.to_csv(filename)
+        
 
